==> spip_3.2.11.orig.tar.xz: plugins-dist/forum/lang/forum_cs.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=cs
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_radio_articles_futurs' => 'pouze k budoucím článkům (žádná akce v databázi).',
	'bouton_radio_articles_tous' => 'ke všem článkům bez výjimky.',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'ke všem článkům s výjimkou těch, kde je vypnutá diskusní skupina.',
	'bouton_radio_enregistrement_obligatoire' => 'Povinná registrace (uživatelé se musí nejprve přihlásit zadáním své elektronické adresy a teprve potom mohou zasílat své příspěvky).',
	'bouton_radio_moderation_priori' => 'Moderovaná skupina (příspěvky
 budou zveřejněny až po schválení jedním
 ze správců).', # MODIF
	'bouton_radio_modere_abonnement' => 'na základě přihlášení',
	'bouton_radio_modere_posteriori' => 'moderování ex post', # MODIF
	'bouton_radio_modere_priori' => 'moderování předem', # MODIF
	'bouton_radio_publication_immediate' => 'Okamžité zveřejňování zpráv
 (příspěvky se zobrazují okamžitě,
 správci je mohou odstranit dodatečně).',

	// D
	'documents_interdits_forum' => 'Dokumenty jsou ve fóru zakázané',

	// F
	'form_pet_message_commentaire' => 'Chcete nám něco sdělit nebo máte nějaké připomínky?',
	'forum' => 'Fórum',
	'forum_acces_refuse' => 'K těmto diskusním skupinám již nemáte přístup.',
	'forum_attention_dix_caracteres' => '<b>Varování!</b> Zpráva musí obsahovat minimálně deset znaků.',
	'forum_attention_trois_caracteres' => '<b>Varování!</b> Název musí obsahovat minimálně deset znaků.',
	'forum_attention_trop_caracteres' => '<b>Varování !</b> vaše zpráva je příliš dlouhá(@compte@ znaků) : aby jí bylo možné uložit, nesmí obsahovat více než  @max@ znaků.', # MODIF
	'forum_avez_selectionne' => 'Zvolili jste:',
	'forum_cliquer_retour' => 'Pokračujte klepnutím <a href=\'@retour_forum@\'>na tento odkaz</a>.',
	'forum_forum' => 'diskusní skupina',
	'forum_info_modere' => 'Tato diskusní skupina je moderovaná: vaše příspěvky se zobrazí až po schválení správcem tohoto webu.', # MODIF
	'forum_lien_hyper' => '<b>Hypertextový odkaz</b> (volitelné)', # MODIF
	'forum_message_definitif' => 'Závěrečná zpráva: odesláno na web',
	'forum_message_trop_long' => 'Zpráva je příliš dlouhá. Maximum je 20.000 znaků.', # MODIF
	'forum_ne_repondez_pas' => 'Neodpovídejte na tuto zprávu. Odpověď zveřejněte v rámci skupiny na adrese:', # MODIF
	'forum_page_url' => '(Týká-li se zpráva článku zveřejněného na webu nebo stránky s doplňujícími informacemi, zadejte dále název stránky a její adresu).',
	'forum_poste_par' => 'Zpráva od posted@parauteur@ na základě vašeho článku.', # MODIF
	'forum_qui_etes_vous' => '<b>Kdo jste?</b> (volitelné)', # MODIF
	'forum_texte' => 'Text zprávy:', # MODIF
	'forum_titre' => 'Předmět:', # MODIF
	'forum_url' => 'Adresa URL:', # MODIF
	'forum_valider' => 'Potvrdit výběr',
	'forum_voir_avant' => 'Před odesláním zprávu zobrazit', # MODIF
	'forum_votre_email' => 'Váš e-mail:', # MODIF
	'forum_votre_nom' => 'Vaše jméno (resp. přezdívka):', # MODIF
	'forum_vous_enregistrer' => 'Této diskusní skupiny se můžete účastnit
  až po zaregistrování. Děkujeme vám
  za zadání identifikačních údajů.
  Nejste-li doposud zaregistrováni, musíte ',
	'forum_vous_inscrire' => 'tak učinit nyní.',

	// I
	'icone_poster_message' => 'Odeslat zprávu',
	'icone_suivi_forum' => 'Sledování veřejné diskusní skupiny: @nb_forums@ příspěvky',
	'icone_suivi_forums' => 'Správa diskusních skupin',
	'icone_supprimer_message' => 'Ostranit zprávu',
	'icone_valider_message' => 'Schválit zprávu',
	'info_activer_forum_public' => '<i>Chcete-li zapnout veřejné diskusní skupiny musíte zvolit jejich 
 standardní způsob moderování:</i>', # MODIF
	'info_appliquer_choix_moderation' => 'Použít tento způsob moderování:',
	'info_desactiver_forum_public' => 'Vypnout veřejné diskusní skupiny
. Tyto skupiny bude možno zapnout ad hoc
 u jednotlivých článků; budou zakázány u sekcí, novinek atd.',
	'info_envoi_forum' => 'Zasílání diskusních skupin autorům článků',
	'info_fonctionnement_forum' => 'Fungování diskusní skupiny:',
	'info_gauche_suivi_forum_2' => 'Stránka pro <i>sledování diskusních skupin</i> je určena ke správě vašeho webu (nejedná se o prostor pro diskusi ani pro redigování). Jsou na ní zobrazeny všechny diskusní příspěvky z veřejné skupiny a umožňuje vám jejich správu.', # MODIF
	'info_liens_syndiques_3' => 'diskusní skupiny',
	'info_liens_syndiques_4' => 'jsou',
	'info_liens_syndiques_5' => 'diskusní skupina',
	'info_liens_syndiques_6' => 'je',
	'info_liens_syndiques_7' => 'čekající na schválení.',
	'info_mode_fonctionnement_defaut_forum_public' => 'Standardní režim veřejných diskusních skupin',
	'info_option_email' => 'Autoři článku mohou být informováni emailem o tom, že návštěvníci
  webu poslali zprávu do diskusní skupiny, týkající se
  jejich článku. Chcete tuto možnost použít?', # MODIF
	'info_pas_de_forum' => 'bez diskusní skupiny',
	'item_activer_forum_administrateur' => 'Zapnout diskusní skupinu správců',
	'item_desactiver_forum_administrateur' => 'Vypnout diskusní skupinu správců',

	// L
	'lien_reponse_article' => 'Odpověď na článek',
	'lien_reponse_breve_2' => 'Odpověď na novinku',
	'lien_reponse_rubrique' => 'Odpověď na sekci',
	'lien_reponse_site_reference' => 'Odpověď na web, na nějž vede odkaz:', # MODIF

	// O
	'onglet_messages_internes' => 'Interní zprávy',
	'onglet_messages_publics' => 'Veřejné zprávy',
	'onglet_messages_vide' => 'Zprávy bez textu',

	// R
	'repondre_message' => 'Reagovat na tuto zprávu',

	// T
	'titre_cadre_forum_administrateur' => 'Soukromá diskusní skupina správců',
	'titre_cadre_forum_interne' => 'Interní diskusní skupina',
	'titre_forum' => 'Diskusní skupina',
	'titre_forum_suivi' => 'Sledování diskusních skupin',
	'titre_page_forum_suivi' => 'Sledování diskusních skupin'
);

==> spip_4.2.13+dfsg.orig.tar.xz: plugins-dist/forum/lang/forum_cs.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=cs
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_radio_articles_futurs' => 'pouze k budoucím článkům (žádná akce v databázi).',
	'bouton_radio_articles_tous' => 'ke všem článkům bez výjimky.',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'ke všem článkům s výjimkou těch, kde je vypnutá diskusní skupina.',
	'bouton_radio_enregistrement_obligatoire' => 'Povinná registrace (uživatelé se musí nejprve přihlásit zadáním své elektronické adresy a teprve potom mohou zasílat své příspěvky).',
	'bouton_radio_moderation_priori' => 'Moderovaná skupina (příspěvky
 budou zveřejněny až po schválení jedním
 ze správců).', # MODIF
	'bouton_radio_modere_abonnement' => 'na základě přihlášení',
	'bouton_radio_modere_posteriori' => 'moderování ex post', # MODIF
	'bouton_radio_modere_priori' => 'moderování předem', # MODIF
	'bouton_radio_publication_immediate' => 'Okamžité zveřejňování zpráv
 (příspěvky se zobrazují okamžitě,
 správci je mohou odstranit dodatečně).',

	// D
	'documents_interdits_forum' => 'Dokumenty jsou ve fóru zakázané',

	// F
	'form_pet_message_commentaire' => 'Chcete nám něco sdělit nebo máte nějaké připomínky?',
	'forum' => 'Fórum',
	'forum_acces_refuse' => 'K těmto diskusním skupinám již nemáte přístup.',
	'forum_attention_dix_caracteres' => '<b>Varování!</b> Zpráva musí obsahovat minimálně deset znaků.',
	'forum_attention_trois_caracteres' => '<b>Varování!</b> Název musí obsahovat minimálně deset znaků.',
	'forum_attention_trop_caracteres' => '<b>Varování !</b> vaše zpráva je příliš dlouhá(@compte@ znaků) : aby jí bylo možné uložit, nesmí obsahovat více než  @max@ znaků.', # MODIF
	'forum_avez_selectionne' => 'Zvolili jste:',
	'forum_cliquer_retour' => 'Pokračujte klepnutím <a href=\'@retour_forum@\'>na tento odkaz</a>.',
	'forum_forum' => 'diskusní skupina',
	'forum_info_modere' => 'Tato diskusní skupina je moderovaná: vaše příspěvky se zobrazí až po schválení správcem tohoto webu.', # MODIF
	'forum_lien_hyper' => '<b>Hypertextový odkaz</b> (volitelné)', # MODIF
	'forum_message_definitif' => 'Závěrečná zpráva: odesláno na web',
	'forum_message_trop_long' => 'Zpráva je příliš dlouhá. Maximum je 20.000 znaků.', # MODIF
	'forum_ne_repondez_pas' => 'Neodpovídejte na tuto zprávu. Odpověď zveřejněte v rámci skupiny na adrese:', # MODIF
	'forum_page_url' => '(Týká-li se zpráva článku zveřejněného na webu nebo stránky s doplňujícími informacemi, zadejte dále název stránky a její adresu).',
	'forum_poste_par' => 'Zpráva od posted@parauteur@ na základě vašeho článku.', # MODIF
	'forum_qui_etes_vous' => '<b>Kdo jste?</b> (volitelné)', # MODIF
	'forum_texte' => 'Text zprávy:', # MODIF
	'forum_titre' => 'Předmět:', # MODIF
	'forum_url' => 'Adresa URL:', # MODIF
	'forum_valider' => 'Potvrdit výběr',
	'forum_voir_avant' => 'Před odesláním zprávu zobrazit', # MODIF
	'forum_votre_email' => 'Váš e-mail:', # MODIF
	'forum_votre_nom' => 'Vaše jméno (resp. přezdívka):', # MODIF
	'forum_vous_enregistrer' => 'Této diskusní skupiny se můžete účastnit
  až po zaregistrování. Děkujeme vám
  za zadání identifikačních údajů.
  Nejste-li doposud zaregistrováni, musíte ',
	'forum_vous_inscrire' => 'tak učinit nyní.',

	// I
	'icone_poster_message' => 'Odeslat zprávu',
	'icone_suivi_forum' => 'Sledování veřejné diskusní skupiny: @nb_forums@ příspěvky',
	'icone_suivi_forums' => 'Správa diskusních skupin',
	'icone_supprimer_message' => 'Ostranit zprávu',
	'icone_valider_message' => 'Schválit zprávu',
	'info_activer_forum_public' => '<i>Chcete-li zapnout veřejné diskusní skupiny musíte zvolit jejich 
 standardní způsob moderování:</i>', # MODIF
	'info_appliquer_choix_moderation' => 'Použít tento způsob moderování:',
	'info_desactiver_forum_public' => 'Vypnout veřejné diskusní skupiny
. Tyto skupiny bude možno zapnout ad hoc
 u jednotlivých článků; budou zakázány u sekcí, novinek atd.',
	'info_envoi_forum' => 'Zasílání diskusních skupin autorům článků',
	'info_fonctionnement_forum' => 'Fungování diskusní skupiny:',
	'info_gauche_suivi_forum_2' => 'Stránka pro <i>sledování diskusních skupin</i> je určena ke správě vašeho webu (nejedná se o prostor pro diskusi ani pro redigování). Jsou na ní zobrazeny všechny diskusní příspěvky z veřejné skupiny a umožňuje vám jejich správu.', # MODIF
	'info_liens_syndiques_3' => 'diskusní skupiny',
	'info_liens_syndiques_4' => 'jsou',
	'info_liens_syndiques_5' => 'diskusní skupina',
	'info_liens_syndiques_6' => 'je',
	'info_liens_syndiques_7' => 'čekající na schválení.',
	'info_mode_fonctionnement_defaut_forum_public' => 'Standardní režim veřejných diskusních skupin',
	'info_option_email' => 'Autoři článku mohou být informováni emailem o tom, že návštěvníci
  webu poslali zprávu do diskusní skupiny, týkající se
  jejich článku. Chcete tuto možnost použít?', # MODIF
	'info_pas_de_forum' => 'bez diskusní skupiny',
	'item_activer_forum_administrateur' => 'Zapnout diskusní skupinu správců',
	'item_desactiver_forum_administrateur' => 'Vypnout diskusní skupinu správců',

	// L
	'lien_reponse_article' => 'Odpověď na článek',
	'lien_reponse_breve_2' => 'Odpověď na novinku',
	'lien_reponse_rubrique' => 'Odpověď na sekci',
	'lien_reponse_site_reference' => 'Odpověď na web, na nějž vede odkaz:', # MODIF

	// O
	'onglet_messages_internes' => 'Interní zprávy',
	'onglet_messages_publics' => 'Veřejné zprávy',
	'onglet_messages_vide' => 'Zprávy bez textu',

	// R
	'repondre_message' => 'Reagovat na tuto zprávu',

	// T
	'titre_cadre_forum_administrateur' => 'Soukromá diskusní skupina správců',
	'titre_cadre_forum_interne' => 'Interní diskusní skupina',
	'titre_forum' => 'Diskusní skupina',
	'titre_forum_suivi' => 'Sledování diskusních skupin',
	'titre_page_forum_suivi' => 'Sledování diskusních skupin',
];
